Bachelor 2015 Spoilers: Who Is Alissa Giambrone, Season 19 Contestant? | The Bachelor | Wetpaint
Description: Chris Soules has quite the lady trough to drink from on this Bachelor Season 19 excursion, kicking off on January 5. And one of the foxiest drops in his bu...
Keywords: The Bachelor,TV,News,Bachelor in Paradise,Features,Spoilers,TV Stars,The Bachelorette,The Bachelor,Chris Soules,Season 19,Bachelor 2015,Season 19 Contestants,Alissa Giambrone
Date: 2014-12-29 19:13:00 UTC

Wetpaint

## The Bachelor

Spoiler!

# Bachelor 2015 Spoilers: Who Is Alissa Giambrone, Season 19 Contestant?

Share Tweet
Remind Me To Watch Reward Me

###### Credit: Craig Sjodin/ABC Television Group © 2014 Disney

Chris Soules has quite the lady trough to drink from on this Bachelor Season 19 excursion, kicking off on January 5. And one of the foxiest drops in his bucket of babes is Alissa Giambrone!

The raven-haired gal bares a striking resemblance to a former Bachelorette who may have broken Chris’s heart last season, with her shiny locks and sparkling eyes. So, what else makes her perfect for Prince Farming? Read on, gentle reader.

The 24-year-old from Hamilton, New Jersey was likely the quickest packer of the 30 gals cast on The Bachelor 2015, as she works as a flight attendant. Unfortunately for her, producers sent the lucky ladies on a bizarre tour of ‘Merica rather than letting them dip their toes into foreign oceans. When Alissa isn’t flying the friendly skies, she keeps her head on her shoulders with “family, friends, laughter, hope, and faith,” according to her official ABC bio.

Should you want to hop aboard her social media flight, you’re a bit outta luck. Miss Alissa’s Facebook is currently deactivated, and you’ll need a boarding pass to her Instagram, as it’s set to private. Her LinkedIn is also seemingly out of date, as it says she works for Gallo Winery. Needless to say, that job likely gave her the skills needed to hang tough for the hours of drinking before rose ceremonies.

Girlfriend keeps it limber between flights with her love of yoga, and she even earned a certificate in being bendy. Let’s hope things work out with Herr Soules, because they might get a touch awkward if not — Alissa says her greatest fear is running into recent exes. She even admits that she once stalked a crush hardcore — and then texted him her findings on accident. Yikes.

But just in case you’re wondering, Alissa made the Dean’s List at St. Joseph’s, where she studied business. To sum her up, let’s turn to the gal’s description of her spirit animal: “A wild mustang. Free to run and explore, they're unpredictable and beautiful, and are loyal to their herd.” If that’s not a winning Bachelor contestant, we don’t know who is.

Do you think Alissa is Chris’ perfect match? Sound off in the comments below.

Sources: Reality Steve, ABC, LinkedIn
December 29, 2014 at 02:13PM EST by Julia Wayne

##### Related:

The Bachelor, Bachelor in Paradise, Chris Soules, Features, News, Spoilers, TV, TV Stars, The Bachelorette,
- Season 19,
- Bachelor 2015,
- Season 19 Contestants,
- Alissa Giambrone

More

#### Watch and Earn

More

#### Hot TV

- ##### Dancing With The Stars

- ##### Downton Abbey

- ##### Pretty Little Liars

- ##### Teen Mom

More

#### Popular

- ##### Pretty Little Liars Season 5B: 7 Questions We Want Answered

#### You Might Like

You've read of 5 maximum articles this month.
GET UNLIMITED ACCESS WHEN YOU UPGRADE TO VIP ›

###### Register now to become a Wetpaint VIP

Perks include access to all Wetpaint content, secret links to exclusive video, and best of all, points earnings and rewards from our partner, Viggle.

Tell me more or sign me up (just click below)
Connect with Facebook
CLOSE